@@ -27,7 +27,6 @@
 #include "gnome-db-i18n.h"
 #include <gconf/gconf.h>
 #include <libgda/gda-data-model-array.h>
-#include <libgda/gda-log.h>
 #include <libgnomedb/gnome-db-config.h>
 
 static GList *
@@ -489,20 +488,9 @@ gnome_db_config_set_boolean (const gchar * path, gboolean new_value)
 void
 gnome_db_config_remove_section (const gchar * path)
 {
-	GSList *slist, *iter;
-	const gchar *key;
 	g_return_if_fail (path != NULL);
 	
-	slist = gconf_client_all_entries (get_conf_client (), path, NULL);
-	for (iter = slist; iter != NULL; iter = iter->next) {
-		GConfEntry *entry = iter->data;
-		
-		key = gconf_entry_get_key (entry);
-		gconf_client_unset (get_conf_client (), key, NULL);
-		gconf_entry_free (entry);
-	}
-	g_slist_free (slist);
-		
+	gconf_client_recursive_unset (get_conf_client (), path, 0, NULL);	
 }
 
 /**
