@@ -44,8 +44,10 @@ client_notification_cb (GdaClient *client,
 	case GDA_CLIENT_EVENT_ERROR :
 		dialog = gnome_db_error_dialog_new (_("Error"));
 		gnome_db_error_dialog_show_errors (GNOME_DB_ERROR_DIALOG (dialog),
-						   gda_connection_get_errors (cnc));
+						   (GList *) gda_connection_get_errors (cnc));
+		break;
 	default :
+		break;
 	}
 }
 
